breed                 [prey a-prey]  
breed                 [predators predator]
breed                 [manager]
breed                 [nodes node]
breed                 [donothing]
undirected-link-breed [edges edge]
turtles-own           [nodesize
                       nodenum
                       my-node
                       my-desired-node
                       node-degree
                       
                       predens
                       dist-pred
                       
                       preydens
                       dist-prey
                       ]
nodes-own             [crowding
                       erosion
                       recovery
                       preyhere
                       predhere
                       time2
                       action
                       time-recovery
                       real_lag]
edges-own             [origdist
                       dist 
                       dist-previous
                      ]  
globals              [time
                      nodesize1
                      nodesize2
                      cost
                      pri
                      changes 
                      
                      ;;predators related globals
                      initial-number-predators
                      pred1
                      pred2
                      predator-reproduce
                      predator-death-rate
                      predation
                      predmove
                      min-pred1
                      min-pred2
                      max-pred1
                      max-pred2
                      pred-migrants
                      pred-extinction-time
                      
                      ;; prey related globals
                      initial-number-prey
                      prey1
                      prey2
                      prey-reproduce
                      preymove
                      min-prey1
                      min-prey2
                      max-prey1
                      max-prey2
                      prey-migrants
                      prey-extinction-time
                     
                      ;;density changing points that depend on the dispersal curve
                      preydens-up
                      preydens-low
                      predens-up
                      coexistence
                     ]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;SETUP AND GO MAIN PROCEDURES;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to setup
  setup-one
  landscape-one
  landscape-two
  preypop
  predpop
  managerpop
  distribute
  if (montecarlo? = "yes") [
      pred-prey-initialize-monte
  ]
  if (montecarlo? = "no") [
    pred-prey-initialize-fixed
  ]
  density
  value-setting
end

to go
  if not any? prey or not any? predators [stop]
  if time = 4000 [
    stop
  ]
  
  ;;predator-prey procedures on the landscape
  ask nodes [set-dens]  
  ask prey [set-dens]
  ask predators [set-dens]
  set prey-migrants 0
  set pred-migrants 0
  ask prey[
    reproduce-prey
    ifelse (preydens < preydens-up) and (predens < predens-up) [
      if (random-float 1 < (preydens / preydens-up) ^ n) or (random-float 1 < (predens / predens-up) ^ n)[
        move-prey
      ]
    ]
    [move-prey] 
  ]
  ask predators [
    catch-prey     ;;if successfull the predator will be able to reproduce according to the reproduce-predator procedure
    mortpred          
    ifelse preydens > preydens-low [
      if random-float 1 < ((preydens - 1) / (preydens-low - 1)) ^ n [
        move-predators
        ]
    ]
    [move-predators]
  ]
  vegetation
 
  ;;manager procedures, starts following the predators and prey
    
  if (strategy? = "local-veg")[
    local-veg-strat
  ]
  if (strategy? = "global-veg")[
    global-veg-strat
  ]
  if (strategy? = "local-prey")[
    local-prey-strat
  ]
  if (strategy? = "global-prey")[
    global-prey-strat
  ]
  if (strategy? = "local-pred")[
    local-predator-strat
  ]
  if (strategy? = "global-pred")[
    global-predator-strat
  ]
  if (strategy? = "none") [
    none
  ]
  
  datacollection
  set time time + 1
  tick
  
    
end

;;;;;;;;;;;;;;;;;;;;;;;;
;; SETUP PROCEDURES ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;; 

;; setup-one used in order to avoid the number "0" problem
to setup-one
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks
  set-default-shape donothing "triangle"
  create-donothing 1 [set color black]
  ask turtles with [color = black] [die]     ;; the who = 0 dies out before the first report 
end
  
;;setting up the landscape: two nodes, one edge, different distances and so on. First we create the nodes, than the edges. 
;;In case of more than two landscape patches, we always deal with a fully connected network, 
;;as weights on edges (dist) are the "cost of movement" from one patch to another.

to landscape-one
  set-default-shape nodes "circle"
  create-nodes numnodes 
    [
      set color green
      set size 3
      set nodesize capacity     
      if nodesize = 0 [set nodesize 1]
      set nodenum [who] of self  ; to distinguish between nodes and habibtat of species                  
      set label nodenum                        
      set time2 time-lag
      set real_lag time-lag
      set action 0
      setxy random-xcor random-ycor
    ]  
end

to landscape-two
   ask nodes [
     create-edges-with other turtles
     set node-degree count edge-neighbors
   ]
   ask edges [
     set dist edge-distance
     set dist-previous dist
     set origdist dist
     set cost dist
   ]
end

;; setting up agents: prey, predators and the manager that acts upon the system
to preypop
  set-default-shape prey "square"
  set initial-number-prey random-poisson 250 
  create-prey initial-number-prey * numnodes
    [
      set color white
      set label-color blue - 2
      set nodenum 0
      setxy random-xcor random-ycor
      hide-turtle
    ]
end

to predpop
  set-default-shape predators "square"
  set initial-number-predators random-poisson 100
  create-predators initial-number-predators * numnodes
    [
      set color red
      set nodenum 0
      setxy random-xcor random-ycor
      hide-turtle
    ]  
end

to managerpop
  set-default-shape manager "triangle"
  create-manager 1  [hide-turtle]
end

;;in order to equally distribute predators and prey on the different landscape patches at the beginning of the simulation
to distribute
  let j 0
  while [j < numnodes] [
    ask n-of initial-number-prey prey with [nodenum = 0] [
      set nodenum j + 1
      set my-node one-of nodes with [nodenum = [nodenum] of myself]
    ]
    ask n-of initial-number-predators predators with [nodenum = 0] [
      set nodenum j + 1
      set my-node one-of nodes with [nodenum = [nodenum] of myself]  
    ]
    set j j + 1  
  ]
end
;;initialization of proper parameters for predators and prey. It is here reported so as to facilitated possible changes in the initial configuration
to pred-prey-initialize-monte
  set predator-reproduce random-poisson 50 
  set prey-reproduce random-poisson 25  
  set predation random-poisson 20  
  set predator-death-rate random-poisson 6  
  let tic (random-poisson 900) / 1000
  let tac (random-poisson 300) / 1000
  let toe (random-poisson 700) / 1000
  ifelse tic < 1 [set preydens-up tic][set preydens-up 1]  
  ifelse tac < 1 [set preydens-low tac][set preydens-low 1]  
  ifelse toe < 1 [set predens-up toe][set predens-up 1]   
  set preymove random-poisson 30  
  set predmove random-poisson 60
  set pred-extinction-time 4001
  set prey-extinction-time 4001
end

to pred-prey-initialize-fixed
  set predator-reproduce 50 
  set prey-reproduce 25  
  set predation 90  
  set predator-death-rate 6  
  let tic (random-poisson 900) / 1000
  let tac (random-poisson 300) / 1000
  let toe (random-poisson 700) / 1000
  ifelse tic < 1 [set preydens-up tic][set preydens-up 1]  
  ifelse tac < 1 [set preydens-low tac][set preydens-low 1]  
  ifelse toe < 1 [set predens-up toe][set predens-up 1]   
  set preymove 30  
  set predmove 60
  set pred-extinction-time 4001
  set prey-extinction-time 4001   
end

to density
  ask prey [
    set-dens
    set-dist-prey
  ]
  ask predators [
    set-dens
    set-dist-pred
  ]   
  ask nodes [
    set my-node self       ;so nodes can also run the 'set-dens' code with no errors
    set-dens
  ]  
end

;;;;;;;;;;;SUBROUTINES FOR THE DENSITY PROCEDURE;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;set-dens is used in the setup and during the go procedure, it is here reported to follow the order with which procedures appear and are executed
to set-dens
  set nodesize [nodesize] of my-node
  if nodesize = 0 [set nodesize 1]
  set preydens ((count prey with [nodenum = [nodenum]  of myself]) / nodesize)
  set predens ((count predators with [nodenum = [nodenum] of myself]) / nodesize)
end

to set-dist-prey
  set dist-prey preymove   
end

to set-dist-pred
  set dist-pred predmove  
end
;;;;;;;;;;;;END OF SUBROUTINES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to value-setting
  set prey1 count prey with [nodenum = 1]
  set prey2 count prey with [nodenum = 2] 
  
  set pred1 count predators with [nodenum = 1]
  set pred2 count predators with [nodenum = 2]
  
  set nodesize1 capacity
  set nodesize2 capacity
  
  set min-prey1 2 * capacity         ;resets the minimum and maximum prey population
  set min-prey2 2 * capacity
  set max-prey1 0
  set max-prey2 0
  set min-pred1 2 * capacity
  set min-pred2 2 * capacity
  set max-pred1 0
  set max-pred2 0 
  
  set coexistence 0
  set changes 1 
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;GO PROCEDURES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  

;;procedures related to PREY population;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to reproduce-prey
  if (random-float 1) < (1 - exp (-1 * (prey-reproduce / 100) * (1 - preydens))) [
    hatch 1 [set nodenum [nodenum] of myself]
  ]  
end

to move-prey
  let rand random-float 1
  ifelse any? ([edge-neighbors] of my-node) with [rand <= ([dist-prey] of myself)/([dist] of edge [who] of self [who] of [my-node] of myself)] [
    set my-desired-node one-of ([edge-neighbors] of my-node) with [rand <= ([dist-prey] of myself)/([dist] of edge [who] of self [who] of [my-node] of myself)]
    set nodenum [nodenum] of my-desired-node
    set my-node one-of nodes with [nodenum = [nodenum] of myself]
    set nodesize [nodesize] of my-node
    set preydens ((count prey with [nodenum = [nodenum]  of myself]) / nodesize)
    set predens ((count predators with [nodenum = [nodenum]  of myself]) / nodesize)
    ifelse (preydens > preydens-up) or (predens > predens-up)
      [die
      ] 
      [set prey-migrants prey-migrants + 1
      ] 
  ]
  [die]
end

;;procedures related to PREDATOR population;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to reproduce-predators
  if random-float 100 < predator-reproduce [
    hatch 1 [set nodenum [nodenum] of myself]  
  ]
end

to catch-prey
  if any? prey with [nodenum = [nodenum] of myself] [
    if (random-float 1) < (1 - exp (-1 * predation * (preydens) / 100)) [
      let victim one-of prey with [nodenum = [nodenum] of myself]
      ask victim [ die ]
      reproduce-predators
    ]
  ]
end                                                 

to move-predators
  let sand random-float 1
   ifelse any? ([edge-neighbors] of my-node) with [sand <= ([dist-pred] of myself)/([dist] of edge [who] of self [who] of [my-node] of myself)][
     set my-desired-node one-of ([edge-neighbors] of my-node) with [sand <= ([dist-pred] of myself)/([dist] of edge [who] of self [who] of [my-node] of myself)]
     set nodenum [nodenum] of my-desired-node
     set my-node one-of nodes with [nodenum = [nodenum] of myself]
     set nodesize [nodesize] of my-node
     set preydens ((count prey with [nodenum = [nodenum]  of myself]) / nodesize)
     ifelse preydens < preydens-low [
       die
       ] 
     [set pred-migrants pred-migrants + 1
     ]
   ]
   [die]
end

to mortpred
  if (random-float 1) < (1 - exp (-1 * predator-death-rate / 100)) [die] 
end

;;;;;;;;;;;;;;;Procedure for vegetation update;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to vegetation
  ask nodes [
    set crowding count prey with [nodenum = [nodenum] of myself]
    set erosion nodesize - (0.4 * nodesize)
    set recovery nodesize - (0.9 * nodesize)
    if crowding >= erosion [
      set nodesize nodesize - 1
    ]
    if crowding < recovery [
      set nodesize nodesize + 1
      if nodesize > capacity [
        set nodesize capacity
      ]
    ]
  ]
end


;; procedures related to MANAGER STRATEGIES;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;;If local strategy, a manager will look only at one single node, if global, he will look at all the nodes in the landscape.
;;The manager, due to constraints in the real world, is able only to monitor one between vegetation cover (i.e. capacity), prey or predators. 
;;Either on one single node or on the network, depending if he aims for a local or global strategy.

;;local = 1 node, global look on both nodes
;; prey min decrease, prey max increase
;; pred min decrease, pred max increase
;; vegetation min increase

to local-veg-strat
  ask node 1 [
    if nodesize <= capthup * nodesize [
      ask edge 1 2[
        set dist dist + increase
        set changes changes + increase
        if dist > 1000 [
          set dist 1000
        ]        
      ]
    ]
    if nodesize >= capthlow * nodesize[
      ask edge 1 2 [
        set dist dist - decrease
        set changes changes + decrease
        if dist < 1 [
          set dist 1
        ]
      ]
    ]
  ]
  
end

to local-prey-strat
  ask node 1 [
    if (prey1 / nodesize1) <= prey-manlow [
      ask edge 1 2 [
        set dist dist - decrease
        set changes changes + decrease
        if dist < 1 [
          set dist 1
        ]
      ]      
    ]
    if prey1 / nodesize1 >= prey-manup [
      ask edge 1 2 [
        set dist dist + increase
        set changes changes + increase
        if dist > 1000 [
          set dist 1000
        ]        
      ]
    ] 
  ]
end

to local-predator-strat
  ask node 1 [
    if (pred1 / nodesize1) <= pred-manlow [
      ask edge 1 2 [
        set dist dist - decrease
        set changes changes + decrease
        if dist < 1 [
          set dist 1
        ]
      ]      
    ]
    if pred1 / nodesize1 >= pred-manup [
      ask edge 1 2 [
        set dist dist + increase
        set changes changes + increase
        if dist > 1000 [
          set dist 1000
        ]
      ]
    ] 
  ]
end

to global-veg-strat
  ask nodes [
    if nodesize <= capthup * nodesize [
      set action 1
    ]
    if nodesize >= capthlow * nodesize [
      set action 2
    ]
  ]
  if [action] of node 1 = 1 or [action] of node 2 = 1 and [action] of node 1 != 2 or [action] of node 2 != 2 [
    ask edge 1 2 [
      set dist dist + increase
      set changes changes + increase
      if dist > 1000 [
        set dist 1000
      ]
    ]
  ]
  if [action] of node 1 = 2 or [action] of node 2 = 2 and [action] of node 1 != 1 or [action] of node 2 != 1 [
    ask edge 1 2 [
      set dist dist - decrease
      set changes changes + decrease
      if dist < 1 [
        set dist 1
      ]
    ]
  ]
end

to global-prey-strat
  ask nodes [
    set preyhere count prey with [nodenum = [nodenum] of myself]
    if (preyhere / nodesize) <= prey-manlow [
      set action 1
    ]
    if (preyhere / nodesize) >= prey-manup [
      set action 2
    ]
  ]
  if [action] of node 1 = 1 or [action] of node 2 = 1 and [action] of node 1 != 2 or [action] of node 2 != 2 [
    ask edge 1 2 [
      set dist dist - decrease
       set changes changes + decrease
      if dist < 1 [
        set dist 1
      ]
    ]
  ]
 if [action] of node 1 = 2 or [action] of node 2 = 2 and [action] of node 1 != 1 or [action] of node 2 != 1 [
    ask edge 1 2 [
      set dist dist + increase
      set changes changes + increase
      if dist > 1000 [
        set dist 1000
      ]      
    ]
  ]     
end


to global-predator-strat
  ask nodes [
    set predhere count predators with [nodenum = [nodenum] of myself]
    if (predhere / nodesize) <= pred-manlow [
      set action 1
    ]
    if (predhere / nodesize) >= pred-manup [
      set action 2
    ]
  ]
  if [action] of node 1 = 1 or [action] of node 2 = 1 and [action] of node 1 != 2 or [action] of node 2 != 2 [
    ask edge 1 2 [
      set dist dist - decrease
      set changes changes + decrease
      if dist < 1 [
        set dist 1
      ]
    ]
  ]
 if [action] of node 1 = 2 or [action] of node 2 = 2 and [action] of node 1 != 1 or [action] of node 2 != 1 [
    ask edge 1 2 [
      set dist dist + increase
      set changes changes + increase
      if dist > 1000 [
        set dist 1000
      ]
    ]
  ]   
end

to none
 
end


to datacollection
   if pred-extinction-time = 4001 [
     if not any? predators [
       set pred-extinction-time time
     ]
   ]
   if prey-extinction-time = 4001 [
     if not any? prey [
       set prey-extinction-time time
     ] 
   ]
   set prey1 count prey with [nodenum = 1]
   set prey2 count prey with [nodenum = 2] 
   set pred1 count predators with [nodenum = 1]
   set pred2 count predators with [nodenum = 2]
   ask node 1 [
     set nodesize1 nodesize
   ]
   ask node 2[
     set nodesize2 nodesize
   ]
   set cost [dist] of edge 1 2
 
 ifelse (time mod 100) > 0 [
   if prey1 < min-prey1 [set min-prey1 prey1] 
   if prey2 < min-prey2 [set min-prey2 prey2]
   if prey1 > max-prey1 [set max-prey1 prey1]
   if prey2 > max-prey2 [set max-prey2 prey2]
   if pred1 < min-pred1 [set min-pred1 pred1] 
   if pred2 < min-pred2 [set min-pred2 pred2]
   if pred1 > max-pred1 [set max-pred1 pred1]
   if pred2 > max-pred2 [set max-pred2 pred2]
 ]
 [ set min-prey1 2 * capacity 
   set min-prey2 2 * capacity
   set max-prey1 0
   set max-prey2 0
   set min-pred1 2 * capacity
   set min-pred2 2 * capacity
   set max-pred1 0
   set max-pred2 0 
 ]
 set coexistence coexistence + 1 
end
@#$#@#$#@
GRAPHICS-WINDOW
885
14
1130
271
16
16
6.85
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
3
10
66
43
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
73
10
136
43
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
144
10
207
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
6
84
178
117
numnodes
numnodes
0
10
2
1
1
NIL
HORIZONTAL

TEXTBOX
15
62
165
80
Landscape attributes
11
0.0
1

SLIDER
8
156
180
189
capacity
capacity
0
1000
500
1
1
NIL
HORIZONTAL

SLIDER
352
10
513
43
time-lag
time-lag
0
0
0
0
1
NIL
HORIZONTAL

TEXTBOX
16
198
166
216
Dispersal curve parameter
11
0.0
1

SLIDER
9
218
181
251
n
n
0
100
5
1
1
NIL
HORIZONTAL

CHOOSER
9
276
181
321
strategy?
strategy?
"none" "local-veg" "global-veg" "local-prey" "global-prey" "local-pred" "global-pred"
2

TEXTBOX
20
258
170
276
Manager strategy choices
11
0.0
1

MONITOR
703
120
773
165
Prey 1
prey1
17
1
11

MONITOR
780
120
851
165
Prey 2
prey2
17
1
11

MONITOR
704
277
775
322
Pred 1
pred1
17
1
11

MONITOR
780
276
851
321
Pred 2
pred2
17
1
11

MONITOR
703
168
774
213
Min Prey 1
min-prey1
17
1
11

MONITOR
704
215
775
260
Max Prey 1
max-prey1
17
1
11

MONITOR
780
169
851
214
Min Prey 2
min-prey2
17
1
11

MONITOR
780
216
852
261
Max Prey 2
max-prey2
17
1
11

MONITOR
704
325
775
370
Min Pred 1
min-pred1
17
1
11

MONITOR
781
325
852
370
Min Pred 2
min-pred2
17
1
11

MONITOR
704
373
776
418
Max Pred 1
max-pred1
17
1
11

MONITOR
781
373
852
418
Max Pred 2
max-pred2
17
1
11

SLIDER
185
157
357
190
prey-manup
prey-manup
0
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
185
194
357
227
prey-manlow
prey-manlow
0
1
0.57
0.01
1
NIL
HORIZONTAL

TEXTBOX
191
65
341
83
Manager action thresholds
11
0.0
1

CHOOSER
211
10
349
55
montecarlo?
montecarlo?
"yes" "no"
0

MONITOR
679
10
736
55
NIL
cost
17
1
11

MONITOR
700
59
772
104
Capacity 1
nodesize1
17
1
11

MONITOR
777
59
849
104
Capacity 2
nodesize2
17
1
11

SLIDER
184
86
356
119
capthup
capthup
0
1
0.6
0.01
1
NIL
HORIZONTAL

SLIDER
185
230
357
263
pred-manup
pred-manup
0
1
0.7
0.01
1
NIL
HORIZONTAL

SLIDER
185
266
357
299
pred-manlow
pred-manlow
0
1
0.25
0.01
1
NIL
HORIZONTAL

TEXTBOX
188
318
393
346
Manager ability to change the landscape
11
0.0
1

SLIDER
187
336
359
369
increase
increase
0
100
50
1
1
NIL
HORIZONTAL

SLIDER
187
372
359
405
decrease
decrease
0
100
50
1
1
NIL
HORIZONTAL

MONITOR
530
10
611
55
Coexistence
coexistence
17
1
11

MONITOR
616
10
675
55
NIL
changes
17
1
11

SLIDER
185
121
357
154
capthlow
capthlow
0
1
0.5
0.01
1
NIL
HORIZONTAL

SLIDER
7
118
179
151
edge-distance
edge-distance
0
1000
1000
1
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

This section could give a general understanding of what the model is trying to show or explain.

## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

This section could contain a reference to the model's URL on the web if it has one, as well as any other necessary credits or references.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="none" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="global-veg" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;global-veg&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="capthup" first="0.5" step="0.1" last="1"/>
    <steppedValueSet variable="capthlow" first="0" step="0.1" last="0.5"/>
    <enumeratedValueSet variable="pred-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="locall-veg" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;local-veg&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <steppedValueSet variable="capthup" first="0.5" step="0.1" last="1"/>
    <steppedValueSet variable="capthlow" first="0" step="0.1" last="0.5"/>
    <enumeratedValueSet variable="pred-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="global-prey" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;global-prey&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="prey-manup" first="0.5" step="0.1" last="1"/>
    <steppedValueSet variable="prey-manlow" first="0" step="0.1" last="0.5"/>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="local-prey" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;local-prey&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pred-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="prey-manup" first="0.5" step="0.1" last="1"/>
    <steppedValueSet variable="prey-manlow" first="0" step="0.1" last="0.5"/>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="global-pred" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;global-pred&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthlow">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="pred-manup" first="0.5" step="0.1" last="1"/>
    <steppedValueSet variable="pred-manlow" first="0" step="0.1" last="0.5"/>
    <enumeratedValueSet variable="prey-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="local-pred" repetitions="400" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>prey1</metric>
    <metric>prey2</metric>
    <metric>pred1</metric>
    <metric>pred2</metric>
    <enumeratedValueSet variable="montecarlo?">
      <value value="&quot;yes&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="strategy?">
      <value value="&quot;local-pred&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="edge-distance">
      <value value="30"/>
      <value value="60"/>
      <value value="100"/>
      <value value="250"/>
      <value value="500"/>
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capthlow">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="pred-manup" first="0.5" step="0.1" last="1"/>
    <steppedValueSet variable="pred-manlow" first="0" step="0.1" last="0.5"/>
    <enumeratedValueSet variable="prey-manup">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prey-manlow">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="numnodes">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-lag">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="capacity">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="increase">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decrease">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
